@@ -11,6 +11,7 @@ from .candidates import (
     CandidateTokenFilterMapper,
     LanguageTokenizerMapper,
     SplitterMapper,
+    TokenClassifilerMapper,
 )
 from .methods import MultiDomainRankingMethodMapper, SingleDomainRankingMethodMapper
 from .pdftoxml import BinaryOpenerMapper
@@ -31,5 +32,6 @@ __all__ = [
     "SplitterMapper",
     "StylingLayerCacheMapper",
     "StylingScoreMapper",
+    "TokenClassifilerMapper",
     "XMLLayerCacheMapper",
 ]
