@@ -2,7 +2,6 @@ from .base import BaseMultiDomainRanker, BaseSingleDomainRanker
 from .flr import FLRRanker
 from .flrh import FLRHRanker
 from .hits import HITSRanker
-from .lfidf import LFIDFRanker
 from .mcvalue import MCValueRanker
 from .mdp import MDPRanker
 from .tfidf import TFIDFRanker
@@ -14,7 +13,6 @@ __all__ = [
     "FLRHRanker",
     "FLRRanker",
     "HITSRanker",
-    "LFIDFRanker",
     "MCValueRanker",
     "MDPRanker",
     "TFIDFRanker",
